==> haskell-esqueleto-3.5.10.1-12-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-esqueleto.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 esqueleto
version:              3.5.10.1
visibility:           public
id:                   esqueleto-3.5.10.1-KRzID0to0tXFppjUQbLZOM
key:                  esqueleto-3.5.10.1-KRzID0to0tXFppjUQbLZOM
license:              BSD-3-Clause
copyright:            (c) 2012-2016 Felipe Almeida Lessa
maintainer:           cma@bitemyapp.com
author:               Felipe Lessa
homepage:             https://github.com/bitemyapp/esqueleto
synopsis:             Type-safe EDSL for SQL queries on persistent backends.
description:
    @esqueleto@ is a bare bones, type-safe EDSL for SQL queries that works with unmodified @persistent@ SQL backends.  Its language closely resembles SQL, so you don'\''t have to learn new concepts, just new syntax, and it'\''s fairly easy to predict the generated SQL and optimize it for your backend. Most kinds of errors committed when writing SQL are caught as compile-time errors---although it is possible to write type-checked @esqueleto@ queries that fail at runtime.

    @persistent@ is a library for type-safe data serialization.  It has many kinds of backends, such as SQL backends (@persistent-mysql@, @persistent-postgresql@, @persistent-sqlite@) and NoSQL backends (@persistent-mongoDB@). While @persistent@ is a nice library for storing and retrieving records, including with filters, it does not try to support some of the features that are specific to SQL backends.  In particular, @esqueleto@ is the recommended library for type-safe @JOIN@s on @persistent@ SQL backends.  (The alternative is using raw SQL, but that'\''s error prone and does not offer any composability.)

    Currently, @SELECT@s, @UPDATE@s, @INSERT@s and @DELETE@s are supported. Not all SQL features are available, but most of them can be easily added (especially functions), so please open an issue or send a pull request if you need anything that is not covered by @esqueleto@ on <https://github.com/bitemyapp/esqueleto>.

    The name of this library means \"skeleton\" in Portuguese and contains all three SQL letters in the correct order =).  It was inspired by Scala'\''s Squeryl but created from scratch.

category:             Database
abi:                  dc5622c9314bed99839a29d10367acd4
exposed:              True
exposed-modules:
    Database.Esqueleto Database.Esqueleto.Experimental
    Database.Esqueleto.Experimental.From
    Database.Esqueleto.Experimental.From.CommonTableExpression
    Database.Esqueleto.Experimental.From.Join
    Database.Esqueleto.Experimental.From.SqlSetOperation
    Database.Esqueleto.Experimental.ToAlias
    Database.Esqueleto.Experimental.ToAliasReference
    Database.Esqueleto.Experimental.ToMaybe
    Database.Esqueleto.Internal.ExprParser
    Database.Esqueleto.Internal.Internal Database.Esqueleto.Legacy
    Database.Esqueleto.MySQL Database.Esqueleto.PostgreSQL
    Database.Esqueleto.PostgreSQL.JSON Database.Esqueleto.Record
    Database.Esqueleto.SQLite

hidden-modules:
    Database.Esqueleto.PostgreSQL.JSON.Instances
    Database.Esqueleto.Internal.PersistentImport Paths_esqueleto

import-dirs:          /usr/lib/ghc-9.4.8/site-local/esqueleto-3.5.10.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/esqueleto-3.5.10.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/esqueleto-3.5.10.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-esqueleto
hs-libraries:         HSesqueleto-3.5.10.1-KRzID0to0tXFppjUQbLZOM
depends:
    aeson-2.1.2.1-Eu0ZMA1fvZJ7acphaZ1YUp
    attoparsec-0.14.4-AaLxHw66o7ZDAbKIqXiED8 base-4.17.2.1
    blaze-html-0.9.2.0-9WgJSHLeSKZHZJZeAqHdGu bytestring-0.11.5.3
    conduit-1.3.6.1-4zipxoOtaf58vXmKwQLSFK containers-0.6.7
    monad-logger-0.3.42-DrHCRPfjPL123BQSo1tVeq
    persistent-2.14.5.2-Ev5HQKPqUxg2yNrYUJogxW
    resourcet-1.2.6-6OalXqf73l86eTJ5NzIFB9
    tagged-0.8.9-KMS3sfDasKWItFZcxfaN6C template-haskell-2.19.0.0
    text-2.0.2 time-1.12.2 transformers-0.5.6.2
    unliftio-0.2.25.1-2e6fOXv3p33BTmCkOacgue
    unordered-containers-0.2.20-5YE9FG6zPmjDjdA4DCPpEY

haddock-interfaces:   /usr/share/doc/haskell-esqueleto/html/esqueleto.haddock
haddock-html:         /usr/share/doc/haskell-esqueleto/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-esqueleto-3.5.10.1-13-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-esqueleto.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 esqueleto
version:              3.5.10.1
visibility:           public
id:                   esqueleto-3.5.10.1-Gx8e9TihuOSLlhocT4OJQb
key:                  esqueleto-3.5.10.1-Gx8e9TihuOSLlhocT4OJQb
license:              BSD-3-Clause
copyright:            (c) 2012-2016 Felipe Almeida Lessa
maintainer:           cma@bitemyapp.com
author:               Felipe Lessa
homepage:             https://github.com/bitemyapp/esqueleto
synopsis:             Type-safe EDSL for SQL queries on persistent backends.
description:
    @esqueleto@ is a bare bones, type-safe EDSL for SQL queries that works with unmodified @persistent@ SQL backends.  Its language closely resembles SQL, so you don'\''t have to learn new concepts, just new syntax, and it'\''s fairly easy to predict the generated SQL and optimize it for your backend. Most kinds of errors committed when writing SQL are caught as compile-time errors---although it is possible to write type-checked @esqueleto@ queries that fail at runtime.

    @persistent@ is a library for type-safe data serialization.  It has many kinds of backends, such as SQL backends (@persistent-mysql@, @persistent-postgresql@, @persistent-sqlite@) and NoSQL backends (@persistent-mongoDB@). While @persistent@ is a nice library for storing and retrieving records, including with filters, it does not try to support some of the features that are specific to SQL backends.  In particular, @esqueleto@ is the recommended library for type-safe @JOIN@s on @persistent@ SQL backends.  (The alternative is using raw SQL, but that'\''s error prone and does not offer any composability.)

    Currently, @SELECT@s, @UPDATE@s, @INSERT@s and @DELETE@s are supported. Not all SQL features are available, but most of them can be easily added (especially functions), so please open an issue or send a pull request if you need anything that is not covered by @esqueleto@ on <https://github.com/bitemyapp/esqueleto>.

    The name of this library means \"skeleton\" in Portuguese and contains all three SQL letters in the correct order =).  It was inspired by Scala'\''s Squeryl but created from scratch.

category:             Database
abi:                  a9b640c9c482d64a097a1f1c0f4dedac
exposed:              True
exposed-modules:
    Database.Esqueleto Database.Esqueleto.Experimental
    Database.Esqueleto.Experimental.From
    Database.Esqueleto.Experimental.From.CommonTableExpression
    Database.Esqueleto.Experimental.From.Join
    Database.Esqueleto.Experimental.From.SqlSetOperation
    Database.Esqueleto.Experimental.ToAlias
    Database.Esqueleto.Experimental.ToAliasReference
    Database.Esqueleto.Experimental.ToMaybe
    Database.Esqueleto.Internal.ExprParser
    Database.Esqueleto.Internal.Internal Database.Esqueleto.Legacy
    Database.Esqueleto.MySQL Database.Esqueleto.PostgreSQL
    Database.Esqueleto.PostgreSQL.JSON Database.Esqueleto.Record
    Database.Esqueleto.SQLite

hidden-modules:
    Database.Esqueleto.PostgreSQL.JSON.Instances
    Database.Esqueleto.Internal.PersistentImport Paths_esqueleto

import-dirs:          /usr/lib/ghc-9.4.8/site-local/esqueleto-3.5.10.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/esqueleto-3.5.10.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/esqueleto-3.5.10.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-esqueleto
hs-libraries:         HSesqueleto-3.5.10.1-Gx8e9TihuOSLlhocT4OJQb
depends:
    aeson-2.1.2.1-HvDDR856aNq5cfhhuYXFVB
    attoparsec-0.14.4-Kqu9azGoeFY4BlHGbH5HBg base-4.17.2.1
    blaze-html-0.9.2.0-LlU0XfzVpg34MJkFx2EZcl bytestring-0.11.5.3
    conduit-1.3.6.1-LSEd28HkJLcLIWho4Hpdv5 containers-0.6.7
    monad-logger-0.3.42-9OgDnhfMjyd9Av4VLmtX3H
    persistent-2.14.5.2-pL8CUNpFRG4IGlDbfxpgZ
    resourcet-1.2.6-7iKUUdP710zAH2Mxgc0pA5
    tagged-0.8.9-KMS3sfDasKWItFZcxfaN6C template-haskell-2.19.0.0
    text-2.0.2 time-1.12.2 transformers-0.5.6.2
    unliftio-0.2.25.1-JjviYpOneZe5nxqbIJEFVH
    unordered-containers-0.2.20-8cMd7edANcDBeBDjVdjsZY

haddock-interfaces:   /usr/share/doc/haskell-esqueleto/html/esqueleto.haddock
haddock-html:         /usr/share/doc/haskell-esqueleto/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
